"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const storage_1 = require("@tonic-foundation/storage");
const bn_js_1 = require("bn.js");
const base_1 = tslib_1.__importStar(require("../base"));
class CreateMarket extends base_1.default {
    async run() {
        const { args, flags } = await this.parse(CreateMarket);
        this.log('Creating market');
        const { executionOutcome, response: marketId } = await this.tonic.createMarket({
            baseTokenId: args.base,
            quoteTokenId: args.quote,
            baseTokenLotSize: new bn_js_1.BN(args.baseLotSize).toString(),
            quoteTokenLotSize: new bn_js_1.BN(args.quoteLotSize).toString(),
            takerFeeBaseRate: parseInt(args.takerFeeBaseRate),
            makerRebateBaseRate: parseInt(args.makerRebateBaseRate),
        });
        this.log(`Created market ${marketId}`);
        this.logTransaction(executionOutcome);
        if (!flags['skip-storage-base'] && args.base !== 'NEAR') {
            this.log(`Performing storage deposit for ${this.globalFlags.contractId} in ${args.base}`);
            this.logTransaction((await (0, storage_1.storageDeposit)(this.account, args.base, {
                accountId: this.globalFlags.contractId,
                registrationOnly: true,
                amount: 0.1,
            })).executionOutcome);
        }
        if (!flags['skip-storage-quote'] && args.quote !== 'NEAR') {
            this.log(`Performing storage deposit for ${this.globalFlags.contractId} in ${args.quote}`);
            this.logTransaction((await (0, storage_1.storageDeposit)(this.account, args.quote, {
                accountId: this.globalFlags.contractId,
                registrationOnly: true,
                amount: 0.1,
            })).executionOutcome);
        }
    }
}
exports.default = CreateMarket;
CreateMarket.description = 'Create a market.';
CreateMarket.examples = [`$ tonic create-market NEAR ft.examples.testnet 100 100`];
CreateMarket.flags = {
    ...base_1.default.flags,
    'skip-storage-base': core_1.Flags.boolean({
        description: 'Skip storage deposit for market in the base token contract',
        default: false,
    }),
    'skip-storage-quote': core_1.Flags.boolean({
        description: 'Skip storage deposit for market in the quote token contract',
        default: false,
    }),
};
CreateMarket.args = [
    {
        name: 'base',
        description: 'Contract ID of the base token. Pass `NEAR` for native NEAR.',
        required: true,
        parse: base_1.parseTokenId,
    },
    {
        name: 'quote',
        description: 'Contract ID of quote token. Pass `NEAR` for native NEAR.',
        required: true,
        parse: base_1.parseTokenId,
    },
    {
        name: 'baseLotSize',
        description: 'Minimum order quantity step size.',
        required: true,
    },
    {
        name: 'quoteLotSize',
        description: 'Minimum price step size.',
        required: true,
    },
    {
        name: 'takerFeeBaseRate',
        description: 'Base rate for the taker fee in bps',
        required: true,
    },
    {
        name: 'makerRebateBaseRate',
        description: 'Base rate for the maker rebate in bps',
        required: true,
    },
];
