"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const bn_js_1 = require("bn.js");
const core_1 = require("@oclif/core");
const base_1 = tslib_1.__importDefault(require("../base"));
const tonic_1 = require("@tonic-foundation/tonic");
const token_1 = require("@tonic-foundation/token");
class GetMarket extends base_1.default {
    async run() {
        const { args } = await this.parse(GetMarket);
        const market = await this.tonic.getMarket(args.marketId);
        const orderbook = await market.getOrderbook(8);
        const [baseToken, quoteToken] = await Promise.all([
            (0, token_1.ftOrNativeNearMetadata)(this.account, market.baseTokenId),
            (0, token_1.ftOrNativeNearMetadata)(this.account, market.quoteTokenId),
        ]);
        const baseSymbol = baseToken.symbol;
        const quoteSymbol = quoteToken.symbol;
        core_1.CliUx.Table.table([
            {
                pair: `${baseSymbol}/${quoteSymbol}`,
                chartingSupport: '',
                baseSymbol,
                quoteSymbol,
                baseTick: market.baseLotSize,
                quoteTick: market.quoteLotSize,
                midmarketPrice: (0, tonic_1.getMidmarketPriceNumber)(orderbook),
                ...orderbook,
            },
        ], {
            pair: {
                header: 'Pair',
            },
            baseTick: {
                header: `Quantity min tick`,
                get: ({ baseSymbol }) => {
                    return `${market.quantityBnToNumber(new bn_js_1.BN(market.baseLotSize))} ${baseSymbol}`;
                },
            },
            quoteTick: {
                header: `Price min tick`,
                get: ({ quoteSymbol }) => {
                    console.log('getting price tick');
                    return `${market.priceBnToNumber(new bn_js_1.BN(market.quoteLotSize))} ${quoteSymbol}`;
                },
            },
            midmarketPrice: {
                header: 'Current price',
                get: ({ midmarketPrice: p }) => p ? `${p} ${quoteSymbol}/${baseSymbol}` : 'No orders',
            },
            asks: {
                header: 'Asks',
                get: ({ asks }) => ordersToString([...asks].reverse(), baseSymbol, quoteSymbol),
            },
            bids: {
                header: 'Bids',
                get: ({ bids }) => ordersToString(bids, baseSymbol, quoteSymbol),
            },
        });
    }
}
exports.default = GetMarket;
GetMarket.description = `Get information about a market by ID`;
GetMarket.examples = [`$ tonic get-market 1746518450595387872`];
GetMarket.args = [
    {
        name: 'marketId',
        description: 'Market ID',
        required: true,
    },
];
function ordersToString(orders, baseSymbol, quoteSymbol) {
    return orders
        .map(([price, quantity]) => `${quantity} ${baseSymbol} @ ${price} ${quoteSymbol}`)
        .join('\n');
}
